Changelog
=========


Version 0.0.2
-------------

Released on 2021-03-13.

New features:

* Support linecap style
* Support line join et miter limit
* Add more cubic Bézier curve options

Bug fixes:

* Don’t include EOL in dictionary length
* Add a second binary line in PDF

Contributors:

* Guillaume Ayoub
* Lucie Anglade
* Alexander Schrijver
* Kees Cook

Backers and sponsors:

* PDF Blocks
* SimonSoft
* Menutech
* Simon Sapin
* Manuel Barkhau
* Andreas Zettl
* Nathalie Gutton
* Tom Pohl
* René Fritz
* Moritz Mahringer
* Florian Demmer
* KontextWork
* Michele Mostarda


Version 0.0.1
-------------

Released on 2020-12-06.

Initial release.

Contributors:

* Guillaume Ayoub
* Lucie Anglade

Backers and sponsors:

* PDF Blocks
* SimonSoft
* Menutech
* Simon Sapin
* Nathalie Gutton
* Andreas Zetti
* Tom Pohl
* Florian Demmer
* Moritz Mahringer
